@@ -575,39 +575,17 @@ class MultiCircuit:
         else:
             raise Exception('Element type not understood ' + str(element_type))
 
-    # def get_Jacobian(self, sparse=False):
-    #     """
-    #     Returns the grid Jacobian matrix.
-    #
-    #     Arguments:
-    #
-    #         **sparse** (bool, False): Return the matrix in CSR sparse format (True) or
-    #         as full matrix (False)
-    #     """
-    #
-    #     numerical_circuit = self.compile_snapshot()
-    #     islands = numerical_circuit.compute()
-    #     i = 0
-    #     # Initial magnitudes
-    #     pvpq = np.r_[islands[i].pv, islands[i].pq]
-    #
-    #     J = Jacobian(Ybus=islands[i].Ybus,
-    #                  V=islands[i].Vbus,
-    #                  Ibus=islands[i].Ibus,
-    #                  pq=islands[i].pq,
-    #                  pvpq=pvpq)
-    #
-    #     if sparse:
-    #         return J
-    #     else:
-    #         return J.todense()
-
-    def apply_lp_profiles(self):
+    def apply_lp_profiles(self, results: "OptimalPowerFlowTimeSeriesResults"):
         """
         Apply the LP results as device profiles.
         """
-        for bus in self.buses:
-            bus.apply_lp_profiles(self.Sbase)
+        generators = self.get_generators()
+        for i, gen in enumerate(generators):
+            gen.P_prof = results.generator_power[:, i]
+
+        loads = self.get_loads()
+        for i, gen in enumerate(loads):
+            gen.P_prof -= results.load_shedding[:, i]
 
     def copy(self):
         """
@@ -685,6 +663,7 @@ class MultiCircuit:
                     self.wire_types,
                     self.transformer_types,
                     self.sequence_line_types]
+            name_prop = ''
 
         elif type_class == 'Wires':
             tpes = self.wire_types
@@ -754,11 +733,8 @@ class MultiCircuit:
     def assign_circuit(self, circ: "MultiCircuit"):
         """
         Assign a circuit object to this object.
-
-        Arguments:
-
-            **circ** (:ref:`MultiCircuit<multicircuit>`):
-            :ref:`MultiCircuit<multicircuit>` object
+        :param circ: Another Circuit instance
+        :return:
         """
         self.buses = circ.buses
 
@@ -1651,7 +1627,7 @@ class MultiCircuit:
 
         return coord.mean(axis=0).tolist()
 
-    def get_boundaries(self, buses):
+    def get_boundaries(self):
         """
         Get the graphic representation boundaries
         :return: min_x, max_x, min_y, max_y
@@ -1662,7 +1638,7 @@ class MultiCircuit:
         max_y = -sys.maxsize
 
         # shrink selection only
-        for bus in buses:
+        for bus in self.buses:
             bus.retrieve_graphic_position()
             x = bus.x
             y = bus.y
@@ -1673,13 +1649,14 @@ class MultiCircuit:
 
         return min_x, max_x, min_y, max_y
 
-    def average_separation(self, branches):
+    def average_separation(self):
         """
         Average separation of the buses
         :param branches: list of Branch elements
         :return: average separation
         """
         separation = 0.0
+        branches = self.get_branch_lists()
         for branch in branches:
             s = np.sqrt((branch.bus_from.x - branch.bus_to.x)**2 + (branch.bus_from.y - branch.bus_to.y)**2)
             separation += s
@@ -1693,11 +1670,9 @@ class MultiCircuit:
         :return: Nothing
         """
 
-        min_x, max_x, min_y, max_y = self.get_boundaries(self.buses)
+        min_x, max_x, min_y, max_y = self.get_boundaries()
 
-        branches = self.lines + self.transformers2w + self.hvdc_lines + self.dc_lines
-
-        sep1 = self.average_separation(branches)
+        sep1 = self.average_separation()
 
         # compute the average point
         xm = (max_x + min_x) / 2
@@ -1890,6 +1865,39 @@ class MultiCircuit:
                 bus.latitude = lat[i]
                 bus.longitude = lon[i]
 
+    def import_bus_lat_lon(self, df: pd.DataFrame, bus_col, lat_col, lon_col):
+        """
+
+        :param df:
+        :param bus_col:
+        :param lat_col:
+        :param lon_col:
+        :return:
+        """
+        logger = Logger()
+        lats = df[lat_col].values
+        lons = df[lon_col].values
+        names = df[bus_col].values
+
+        d = dict()
+        for lat, lon, name in zip(lats, lons, names):
+            d[str(name)] = (lat, lon)
+
+        # assign the values
+        for i, bus in enumerate(self.buses):
+            if bus.name in d.keys():
+                lat, lon = d[bus.name]
+                bus.latitude = lat
+                bus.longitude = lon
+            elif bus.code in d.keys():
+                lat, lon = d[bus.code]
+                bus.latitude = lat
+                bus.longitude = lon
+            else:
+                logger.add_error("No coordinates for bus", bus.name)
+
+        return logger
+
     def import_plexos_load_profiles(self, df: pd.DataFrame):
         """
 
@@ -1942,8 +1950,8 @@ class MultiCircuit:
                 gen.P_prof = df[col_name].values
             except KeyError:
                 logger.add_error("Missing in the model", col_name)
-                gen.P_prof = np.zeros(nn)
-                gen.Q_prof = np.zeros(nn)
+                # gen.P_prof = np.zeros(nn)
+                # gen.Q_prof = np.zeros(nn)
 
         return logger
 
@@ -1963,8 +1971,12 @@ class MultiCircuit:
         cols = list()
         for val in df.columns.values:
             vals = val.split('_')
-            col = vals[0] + '_' + vals[3] + '_' + vals[6]
-            cols.append(col)
+            if len(vals) < 7:
+                logger.add_error("Wrong PSSe name", val)
+                cols.append(val)
+            else:
+                col = vals[0] + '_' + vals[3] + '_' + vals[6]
+                cols.append(col)
         df.columns = cols
 
         branches = self.get_branches()
