@@ -20,14 +20,15 @@ from matplotlib import pyplot as plt
 
 from PySide2.QtCore import QThread, Signal
 
-from GridCal.Engine.Simulations.PowerFlow.power_flow_results import PowerFlowResults
-from GridCal.Engine.Simulations.PowerFlow.power_flow_worker import power_flow_post_process, PowerFlowOptions
+from GridCal.Engine.Simulations.results_template import ResultsTemplate
+from GridCal.Engine.Simulations.PowerFlow.power_flow_worker import PowerFlowOptions
 from GridCal.Engine.Simulations.result_types import ResultTypes
 from GridCal.Engine.Simulations.ContinuationPowerFlow.continuation_power_flow import continuation_nr, CpfStopAt, CpfParametrization, CpfNumericResults
 from GridCal.Engine.Core.multi_circuit import MultiCircuit
 from GridCal.Engine.Core.snapshot_pf_data import compile_snapshot_circuit
 from GridCal.Engine.plot_config import LINEWIDTH
 from GridCal.Engine.Simulations.results_model import ResultsModel
+from GridCal.Engine.Simulations.driver_types import SimulationTypes
 
 
 ########################################################################################################################
@@ -95,7 +96,7 @@ class ContinuationPowerFlowInput:
         self.base_overload_number = base_overload_number
 
 
-class ContinuationPowerFlowResults:
+class ContinuationPowerFlowResults(ResultsTemplate):
 
     def __init__(self, nval, nbus, nbr, bus_names, branch_names, bus_types):
         """
@@ -104,8 +105,31 @@ class ContinuationPowerFlowResults:
         :param nbr: number of branches
         :param bus_names: names of the buses
         """
-
-        self.name = 'Voltage collapse'
+        ResultsTemplate.__init__(self,
+                                 name='Continuation Power Flow',
+                                 available_results=[ResultTypes.BusVoltage,
+                                                    ResultTypes.BusActivePower,
+                                                    ResultTypes.BusReactivePower,
+                                                    ResultTypes.BranchActivePowerFrom,
+                                                    ResultTypes.BranchReactivePowerFrom,
+                                                    ResultTypes.BranchActivePowerTo,
+                                                    ResultTypes.BranchReactivePowerTo,
+                                                    ResultTypes.BranchActiveLosses,
+                                                    ResultTypes.BranchReactiveLosses,
+                                                    ResultTypes.BranchLoading],
+                                 data_variables=['bus_names',
+                                                 'branch_names',
+                                                 'voltages',
+                                                 'lambdas',
+                                                 'error',
+                                                 'converged',
+                                                 'Sf',
+                                                 'St',
+                                                 'loading',
+                                                 'losses',
+                                                 'Sbus',
+                                                 'bus_types']
+                                 )
 
         self.bus_names = bus_names
 
@@ -130,17 +154,6 @@ class ContinuationPowerFlowResults:
 
         self.bus_types = bus_types
 
-        self.available_results = [ResultTypes.BusVoltage,
-                                  ResultTypes.BusActivePower,
-                                  ResultTypes.BusReactivePower,
-                                  ResultTypes.BranchActivePowerFrom,
-                                  ResultTypes.BranchReactivePowerFrom,
-                                  ResultTypes.BranchActivePowerTo,
-                                  ResultTypes.BranchReactivePowerTo,
-                                  ResultTypes.BranchActiveLosses,
-                                  ResultTypes.BranchReactiveLosses,
-                                  ResultTypes.BranchLoading]
-
     def get_results_dict(self):
         """
         Returns a dictionary with the results sorted in a dictionary
@@ -152,14 +165,6 @@ class ContinuationPowerFlowResults:
                 'error': self.error.tolist()}
         return data
 
-    def save(self, fname):
-        """
-        Export as json file
-        """
-        with open(fname, "wb") as output_file:
-            json_str = json.dumps(self.get_results_dict())
-            output_file.write(json_str)
-
     def apply_from_island(self, results: CpfNumericResults, bus_original_idx, branch_original_idx):
         """
         Apply the results of an island to this ContinuationPowerFlowResults instance
@@ -266,7 +271,7 @@ class ContinuationPowerFlowResults:
 
         elif result_type == ResultTypes.BranchLoading:
             labels = self.branch_names
-            y = np.abs(self.loading) * 100.0
+            y = self.loading * 100.0
             x = self.lambdas
             title = 'Branch loading'
             y_label = '%'
@@ -288,6 +293,7 @@ class ContinuationPowerFlowDriver(QThread):
     progress_text = Signal(str)
     done_signal = Signal()
     name = 'Continuation Power Flow'
+    tpe = SimulationTypes.ContinuationPowerFlow_run
 
     def __init__(self, circuit: MultiCircuit,
                  options: ContinuationPowerFlowOptions,
