@@ -27,6 +27,7 @@ from GridCal.Engine.Simulations.OPF.simple_dispatch import OpfSimple
 from GridCal.Engine.basic_structures import SolverType
 from GridCal.Engine.Simulations.PowerFlow.power_flow_driver import PowerFlowOptions
 from GridCal.Engine.Core.snapshot_opf_data import compile_snapshot_opf_circuit
+from GridCal.Engine.Simulations.driver_types import SimulationTypes
 
 ########################################################################################################################
 # Optimal Power flow classes
@@ -71,6 +72,7 @@ class OptimalPowerFlow(QThread):
     progress_text = Signal(str)
     done_signal = Signal()
     name = 'Optimal power flow'
+    tpe = SimulationTypes.OPF_run
 
     def __init__(self, grid: MultiCircuit, options: OptimalPowerFlowOptions, pf_options: PowerFlowOptions):
         """
