@@ -28,6 +28,7 @@ from GridCal.Engine.Simulations.PowerFlow.power_flow_worker import PowerFlowOpti
                                                                     power_flow_worker_args, power_flow_post_process
 
 from GridCal.Engine.Core.time_series_pf_data import compile_time_circuit, BranchImpedanceMode
+from GridCal.Engine.Simulations.driver_types import SimulationTypes
 
 ########################################################################################################################
 # Monte Carlo classes
@@ -64,6 +65,7 @@ class StochasticPowerFlowDriver(QThread):
     progress_text = Signal(str)
     done_signal = Signal()
     name = 'Stochastic Power Flow'
+    tpe = SimulationTypes.StochasticPowerFlow
 
     def __init__(self, grid: MultiCircuit, options: PowerFlowOptions, mc_tol=1e-3, batch_size=100, sampling_points=10000,
                  opf_time_series_results=None,
