@@ -316,6 +316,18 @@ class DcLineGraphicItem(QGraphicsLineItem):
             ra6.setIcon(plot_icon)
             ra6.triggered.connect(self.plot_profiles)
 
+            ra4 = menu.addAction('Assign rate to profile')
+            ra4_icon = QIcon()
+            ra4_icon.addPixmap(QPixmap(":/Icons/icons/assign_to_profile.svg"))
+            ra4.setIcon(ra4_icon)
+            ra4.triggered.connect(self.assign_rate_to_profile)
+
+            ra5 = menu.addAction('Assign active state to profile')
+            ra5_icon = QIcon()
+            ra5_icon.addPixmap(QPixmap(":/Icons/icons/assign_to_profile.svg"))
+            ra5.setIcon(ra5_icon)
+            ra5.triggered.connect(self.assign_status_to_profile)
+
             # menu.addSeparator()
 
             re = menu.addAction('Reduce')
@@ -468,6 +480,18 @@ class DcLineGraphicItem(QGraphicsLineItem):
         i = self.diagramScene.circuit.get_branches().index(self.api_object)
         self.diagramScene.plot_branch(i, self.api_object)
 
+    def assign_rate_to_profile(self):
+        """
+        Assign the snapshot rate to the profile
+        """
+        self.diagramScene.set_rate_to_profile(self.api_object)
+
+    def assign_status_to_profile(self):
+        """
+        Assign the snapshot rate to the profile
+        """
+        self.diagramScene.set_active_status_to_profile(self.api_object)
+
     def setFromPort(self, fromPort):
         """
         Set the From terminal in a connection
