@@ -238,8 +238,10 @@ class DiagramScene(QGraphicsScene):
                 voltage = dict()
 
                 for key, driver in self.circuit.results_dictionary.items():
-                    if key == 'Time Series':
-                        voltage[key] = np.abs(driver.results.voltage[:, i])
+                    if hasattr(driver, 'results'):
+                        if driver.results is not None:
+                            if key == 'Time Series':
+                                voltage[key] = np.abs(driver.results.voltage[:, i])
 
                 # injections
                 if len(power_data.keys()):
@@ -276,6 +278,7 @@ class DiagramScene(QGraphicsScene):
 
         # set time
         x = self.circuit.time_profile
+        x_cl = x
 
         if x is not None:
             if len(x) > 0:
@@ -285,19 +288,32 @@ class DiagramScene(QGraphicsScene):
                 # search available results
                 power_data = dict()
                 loading_data = dict()
+                loading_st_data = None
+                loading_clustering_data = None
+                power_clustering_data = None
 
                 for key, driver in self.circuit.results_dictionary.items():
-                    if key == 'Time Series':
-                        power_data[key] = driver.results.Sf.real[:, i]
-                        loading_data[key] = np.sort(np.abs(driver.results.loading.real[:, i] * 100.0))
+                    if hasattr(driver, 'results'):
+                        if driver.results is not None:
+                            if key == 'Time Series':
+                                power_data[key] = driver.results.Sf.real[:, i]
+                                loading_data[key] = np.sort(np.abs(driver.results.loading.real[:, i] * 100.0))
 
-                    elif key == 'PTDF Time Series':
-                        power_data[key] = driver.results.Sf.real[:, i]
-                        loading_data[key] = np.sort(np.abs(driver.results.loading.real[:, i] * 100.0))
+                            elif key == 'Time Series Clustering':
+                                x_cl = x[driver.sampled_time_idx]
+                                power_clustering_data = driver.results.Sf.real[:, i]
+                                loading_clustering_data = np.sort(np.abs(driver.results.loading.real[:, i] * 100.0))
 
-                    elif key == 'N-1 time series':
-                        power_data[key] = driver.results.worst_flows.real[:, i]
-                        loading_data[key] = np.sort(np.abs(driver.results.worst_loading.real[:, i] * 100.0))
+                            elif key == 'PTDF Time Series':
+                                power_data[key] = driver.results.Sf.real[:, i]
+                                loading_data[key] = np.sort(np.abs(driver.results.loading.real[:, i] * 100.0))
+
+                            elif key == 'N-1 time series':
+                                power_data[key] = driver.results.worst_flows.real[:, i]
+                                loading_data[key] = np.sort(np.abs(driver.results.worst_loading.real[:, i] * 100.0))
+
+                            elif key == 'Stochastic Power Flow':
+                                loading_st_data = np.sort(np.abs(driver.results.loading_points.real[:, i] * 100.0))
 
                 # loading
                 if len(loading_data.keys()):
@@ -306,13 +322,33 @@ class DiagramScene(QGraphicsScene):
                     ax_1.set_ylabel('Loading [%]', fontsize=11)
                     df.plot(ax=ax_1)
 
-                # loading
+                if loading_clustering_data is not None:
+                    p_st = np.arange(len(loading_clustering_data)).astype(float) / len(loading_clustering_data)
+                    df = pd.DataFrame(data=loading_clustering_data, index=p_st, columns=['Clustering Time Series'])
+                    ax_1.set_title('Probability x < value', fontsize=14)
+                    ax_1.set_ylabel('Loading [%]', fontsize=11)
+                    df.plot(ax=ax_1)
+
+                if loading_st_data is not None:
+                    p_st = np.arange(len(loading_st_data)).astype(float) / len(loading_st_data)
+                    df = pd.DataFrame(data=loading_st_data, index=p_st, columns=['Stochastic Power Flow'])
+                    ax_1.set_title('Probability x < value', fontsize=14)
+                    ax_1.set_ylabel('Loading [%]', fontsize=11)
+                    df.plot(ax=ax_1)
+
+                # power
                 if len(power_data.keys()):
                     df = pd.DataFrame(data=power_data, index=x)
                     ax_2.set_title('Power', fontsize=14)
                     ax_2.set_ylabel('Power [MW]', fontsize=11)
                     df.plot(ax=ax_2)
 
+                if power_clustering_data is not None:
+                    df = pd.DataFrame(data=power_clustering_data, index=x_cl, columns=['Clustering Time Series'])
+                    ax_2.set_title('Power', fontsize=14)
+                    ax_2.set_ylabel('Power [MW]', fontsize=11)
+                    df.plot(ax=ax_2)
+
                 plt.legend()
                 fig.suptitle(api_object.name, fontsize=20)
 
@@ -353,6 +389,37 @@ class DiagramScene(QGraphicsScene):
 
                 plt.show()
 
+    def set_rate_to_profile(self, api_object):
+        """
+
+        :param api_object:
+        """
+        if api_object is not None:
+            if api_object.rate_prof is not None:
+                quit_msg = "Are you sure that you want to overwrite the rates profile with the snapshot value?"
+                reply = QMessageBox.question(self.parent_, 'Overwrite the profile', quit_msg, QMessageBox.Yes, QMessageBox.No)
+
+                if reply == QMessageBox.Yes:
+                    api_object.rate_prof *= 0
+                    api_object.rate_prof += api_object.rate
+
+    def set_active_status_to_profile(self, api_object):
+        """
+
+        :param api_object:
+        """
+        if api_object is not None:
+            if api_object.active_prof is not None:
+                quit_msg = "Are you sure that you want to overwrite the rates profile with the snapshot value?"
+                reply = QMessageBox.question(self.parent_, 'Overwrite the profile', quit_msg, QMessageBox.Yes, QMessageBox.No)
+
+                if reply == QMessageBox.Yes:
+                    shape = api_object.active_prof.shape
+                    if api_object.active:
+                        api_object.active_prof = np.ones(shape, dtype=bool)
+                    else:
+                        api_object.active_prof = np.zeros(shape, dtype=bool)
+
     def mouseMoveEvent(self, mouseEvent):
         """
 
@@ -486,7 +553,7 @@ class GridEditor(QSplitter):
 
         self.started_branch = None
 
-        self.setStretchFactor(0, 1)
+        self.setStretchFactor(0, 0)
         self.setStretchFactor(1, 2000)
 
     def start_connection(self, port: TerminalItem):
