@@ -26,16 +26,16 @@ from GridCal.Engine.Simulations.Topology.topology_driver import reduce_grid_brut
 
 class LineEditor(QDialog):
 
-    def __init__(self, branch: Line, Sbase=100, templates=None, current_template=None):
+    def __init__(self, line: Line, Sbase=100, templates=None, current_template=None):
         """
         Line Editor constructor
-        :param branch: Branch object to update
+        :param line: Branch object to update
         :param Sbase: Base power in MVA
         """
         super(LineEditor, self).__init__()
 
         # keep pointer to the line object
-        self.branch = branch
+        self.line = line
 
         self.Sbase = Sbase
 
@@ -54,18 +54,19 @@ class LineEditor(QDialog):
         # ------------------------------------------------------------------------------------------
         # Set the object values
         # ------------------------------------------------------------------------------------------
-        Vf = self.branch.bus_from.Vnom
-        Vt = self.branch.bus_to.Vnom
 
-        Zbase = self.Sbase / (Vf * Vf)
+        Vf = self.line.bus_from.Vnom
+        Vt = self.line.bus_to.Vnom
+
+        Zbase = (Vf * Vf) / self.Sbase
         Ybase = 1 / Zbase
+        length = self.line.length
 
-        R = self.branch.R * Zbase
-        X = self.branch.X * Zbase
-        B = self.branch.B * Ybase
+        R = self.line.R * Zbase / length
+        X = self.line.X * Zbase / length
+        B = self.line.B * Ybase / length
+        I = np.round(self.line.rate / (Vf * 1.73205080757), 6)  # current in kA
 
-        I = self.branch.rate / Vf  # current in kA
-        length = self.branch.length
         # ------------------------------------------------------------------------------------------
 
         # catalogue
@@ -182,24 +183,21 @@ class LineEditor(QDialog):
         I = self.i_spinner.value()
         R = self.r_spinner.value() * l
         X = self.x_spinner.value() * l
-        # G = self.g_spinner.value() * l
         B = self.b_spinner.value() * l
 
-        Vf = self.branch.bus_from.Vnom
-        Vt = self.branch.bus_to.Vnom
+        Vf = self.line.bus_from.Vnom
+        Vt = self.line.bus_to.Vnom
 
-        Sn = np.round(I * Vf, 2)  # nominal power in MVA = kA * kV
-
-        Zbase = self.Sbase / (Vf * Vf)
+        Zbase = (Vf * Vf) / self.Sbase
         Ybase = 1.0 / Zbase
 
-        self.branch.R = np.round(R / Zbase, 6)
-        self.branch.X = np.round(X / Zbase, 6)
-        self.branch.B = np.round(B / Ybase, 6)
-        self.branch.rate = Sn
+        self.line.R = np.round(R / Zbase, 6)
+        self.line.X = np.round(X / Zbase, 6)
+        self.line.B = np.round(B / Ybase, 6)
+        self.line.rate = np.round(I * Vf * 1.73205080757, 6)  # nominal power in MVA = kA * kV
 
         if self.selected_template is not None:
-            self.branch.template = self.selected_template
+            self.line.template = self.selected_template
 
         self.accept()
 
@@ -422,6 +420,18 @@ class LineGraphicItem(QGraphicsLineItem):
             ra6.setIcon(plot_icon)
             ra6.triggered.connect(self.plot_profiles)
 
+            ra4 = menu.addAction('Assign rate to profile')
+            ra4_icon = QIcon()
+            ra4_icon.addPixmap(QPixmap(":/Icons/icons/assign_to_profile.svg"))
+            ra4.setIcon(ra4_icon)
+            ra4.triggered.connect(self.assign_rate_to_profile)
+
+            ra5 = menu.addAction('Assign active state to profile')
+            ra5_icon = QIcon()
+            ra5_icon.addPixmap(QPixmap(":/Icons/icons/assign_to_profile.svg"))
+            ra5.setIcon(ra5_icon)
+            ra5.triggered.connect(self.assign_status_to_profile)
+
             # menu.addSeparator()
 
             re = menu.addAction('Reduce')
@@ -744,6 +754,18 @@ class LineGraphicItem(QGraphicsLineItem):
         if dlg.exec_():
             pass
 
+    def assign_rate_to_profile(self):
+        """
+        Assign the snapshot rate to the profile
+        """
+        self.diagramScene.set_rate_to_profile(self.api_object)
+
+    def assign_status_to_profile(self):
+        """
+        Assign the snapshot rate to the profile
+        """
+        self.diagramScene.set_active_status_to_profile(self.api_object)
+
     def to_transformer(self):
         """
         Convert this object to transformer
