@@ -159,7 +159,7 @@ class TransformerEditor(QDialog):
 
         # add all to the GUI
         if templates is not None:
-            self.layout.addWidget(QLabel("Available templates"))
+            self.layout.addWidget(QLabel("Suitable templates"))
             self.layout.addWidget(self.catalogue_combo)
             self.layout.addWidget(self.load_template_btn)
             self.layout.addWidget(QLabel(""))
@@ -179,6 +179,8 @@ class TransformerEditor(QDialog):
         self.layout.addWidget(QLabel("Vsc: Short circuit voltage [%]"))
         self.layout.addWidget(self.vsc_spinner)
 
+        # self.layout.addWidget(self.system_base_chk)
+
         self.layout.addWidget(self.accept_btn)
 
         self.setLayout(self.layout)
@@ -475,6 +477,18 @@ class TransformerGraphicItem(QGraphicsLineItem):
             ra3.setIcon(ra3_icon)
             ra3.triggered.connect(self.add_to_templates)
 
+            ra4 = menu.addAction('Assign rate to profile')
+            ra4_icon = QIcon()
+            ra4_icon.addPixmap(QPixmap(":/Icons/icons/assign_to_profile.svg"))
+            ra4.setIcon(ra4_icon)
+            ra4.triggered.connect(self.assign_rate_to_profile)
+
+            ra5 = menu.addAction('Assign active state to profile')
+            ra5_icon = QIcon()
+            ra5_icon.addPixmap(QPixmap(":/Icons/icons/assign_to_profile.svg"))
+            ra5.setIcon(ra5_icon)
+            ra5.triggered.connect(self.assign_status_to_profile)
+
             menu.addSection('Tap changer')
 
             ra4 = menu.addAction('Tap up')
@@ -787,6 +801,18 @@ class TransformerGraphicItem(QGraphicsLineItem):
                 tpe = dlg.get_template()
                 self.diagramScene.circuit.add_transformer_type(tpe)
 
+    def assign_rate_to_profile(self):
+        """
+        Assign the snapshot rate to the profile
+        """
+        self.diagramScene.set_rate_to_profile(self.api_object)
+
+    def assign_status_to_profile(self):
+        """
+        Assign the snapshot rate to the profile
+        """
+        self.diagramScene.set_active_status_to_profile(self.api_object)
+
     def tap_up(self):
         """
         Set one tap up
